package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: Jul 13, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Change struct {
Path string `json:"path"`
PreviousPath string `json:"previous_path,omitempty"`
Kind string `json:"kind"`
OldMode string `json:"old_mode,omitempty"`
NewMode string `json:"new_mode,omitempty"`
}
type Diff struct {
Baseline string `json:"baseline"`
Changes []Change `json:"changes"`
Paths []string `json:"paths"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.